@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,11 +20,16 @@ public:
     bool spellCheckingEnabled = false;
 };
 
-RichTextComposerEmailQuoteHighlighter::RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit, const QColor &normalColor, const QColor &quoteDepth1, const QColor &quoteDepth2, const QColor &quoteDepth3, const QColor &misspelledColor)
+RichTextComposerEmailQuoteHighlighter::RichTextComposerEmailQuoteHighlighter(RichTextComposer *textEdit,
+                                                                             const QColor &normalColor,
+                                                                             const QColor &quoteDepth1,
+                                                                             const QColor &quoteDepth2,
+                                                                             const QColor &quoteDepth3,
+                                                                             const QColor &misspelledColor)
     : Sonnet::Highlighter(textEdit)
     , d(new KPIMTextEdit::RichTextComposerEmailQuoteHighlighter::RichTextComposerEmailQuoteHighlighterPrivate())
 {
-    Q_UNUSED(normalColor);
+    Q_UNUSED(normalColor)
     // Don't automatically disable the spell checker, for example because there
     // are too many misspelled words. That would also disable quote highlighting.
     // FIXME: disable this spell checking!
@@ -44,9 +49,13 @@ RichTextComposerEmailQuoteHighlighter::~RichTextComposerEmailQuoteHighlighter()
     delete d;
 }
 
-void RichTextComposerEmailQuoteHighlighter::setQuoteColor(const QColor &normalColor, const QColor &quoteDepth1, const QColor &quoteDepth2, const QColor &quoteDepth3, const QColor &misspelledColor)
+void RichTextComposerEmailQuoteHighlighter::setQuoteColor(const QColor &normalColor,
+                                                          const QColor &quoteDepth1,
+                                                          const QColor &quoteDepth2,
+                                                          const QColor &quoteDepth3,
+                                                          const QColor &misspelledColor)
 {
-    Q_UNUSED(normalColor);
+    Q_UNUSED(normalColor)
     d->col1 = quoteDepth1;
     d->col2 = quoteDepth2;
     d->col3 = quoteDepth3;
@@ -64,8 +73,7 @@ void RichTextComposerEmailQuoteHighlighter::toggleSpellHighlighting(bool on)
 void RichTextComposerEmailQuoteHighlighter::highlightBlock(const QString &text)
 {
     QString simplified = text;
-    simplified.remove(QRegularExpression(QStringLiteral("\\s"))).
-    replace(QLatin1Char('|'), QLatin1Char('>'));
+    simplified.remove(QRegularExpression(QStringLiteral("\\s"))).replace(QLatin1Char('|'), QLatin1Char('>'));
 
     while (simplified.startsWith(QLatin1String(">>>>"))) {
         simplified.remove(0, 3);
@@ -78,19 +86,19 @@ void RichTextComposerEmailQuoteHighlighter::highlightBlock(const QString &text)
     } else if (simplified.startsWith(QLatin1String(">"))) {
         setFormat(0, text.length(), d->col1);
     } else if (d->parent->isLineQuoted(text)) {
-        setFormat(0, text.length(), d->col1);   // FIXME: custom quote prefix
+        setFormat(0, text.length(), d->col1); // FIXME: custom quote prefix
         // can't handle multiple levels
     } else if (d->spellCheckingEnabled) {
         Highlighter::highlightBlock(text);
-        return; //setCurrentBlockState already done in Highlighter::highlightBlock
+        return; // setCurrentBlockState already done in Highlighter::highlightBlock
     }
     setCurrentBlockState(0);
 }
 
 void RichTextComposerEmailQuoteHighlighter::unsetMisspelled(int start, int count)
 {
-    Q_UNUSED(start);
-    Q_UNUSED(count);
+    Q_UNUSED(start)
+    Q_UNUSED(count)
 }
 
 void RichTextComposerEmailQuoteHighlighter::setMisspelled(int start, int count)
