@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #include "texttospeechgui.h"
 #include "texttospeech/texttospeech.h"
 #include <KLocalizedString>
-#include <QApplication>
-#include <QTextEdit>
-#include <QCommandLineParser>
 #include <QAction>
-#include <QMenuBar>
-#include <QMenu>
+#include <QApplication>
+#include <QCommandLineParser>
 #include <QDebug>
+#include <QMenu>
+#include <QMenuBar>
 #include <QStandardPaths>
+#include <QTextEdit>
 
 TextToSpeechGui::TextToSpeechGui(QWidget *parent)
     : QMainWindow(parent)
@@ -57,7 +57,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new TextToSpeechGui;
+    auto w = new TextToSpeechGui;
 
     w->show();
     app.exec();
